summaryrefslogtreecommitdiff
path: root/gtk/gtkwidget.c
diff options
context:
space:
mode:
authorOwen Taylor <otaylor@redhat.com>2001-12-23 22:59:30 +0000
committerOwen Taylor <otaylor@src.gnome.org>2001-12-23 22:59:30 +0000
commitcd6070461e42fa23e1af04add0dcdb3346b2b9a1 (patch)
tree3a4e3e724fdeb93b8280477f58b118da4d519513 /gtk/gtkwidget.c
parent1806c0eed8def0e7e27786e63b670875aa94a8f6 (diff)
downloadgtk+-cd6070461e42fa23e1af04add0dcdb3346b2b9a1.tar.gz
1.3.12, interface, binary age 0.
Sat Dec 22 12:38:03 2001 Owen Taylor <otaylor@redhat.com> * configure.in: 1.3.12, interface, binary age 0. * configure.in: Require new versions of Glib, Pango, ATK. * NEWS: Updated. * configure.in: Make explicit what libtool we are executing. (Tomas Ogren) * gdk/gdkcolor.c gdk/gdkgc.c gdk/gdkwindow.c: Doc fixes. * gtk/gtkwidget.c (gtk_widget_[class]path) gtkrc.h : Fix parameter names for docs. Sat Dec 22 22:35:29 2001 Owen Taylor <otaylor@redhat.com> * gtk/gtkwindow.c (gtk_window_realize) gtk/gtkplug.c (gtk_plug_realize): Include GDK_KEY_RELEASE_MASK. * gtk/gtkentry.c (gtk_entry_key_release) gtk/gtktextview.c (gtk_text_view_key_release_event): Pass key release events to the input method. * gtk/gtkimcontextsimple.c (gtk_im_context_simple_filter_keypress): Handle release of Control/Shift to end hex sequence. * modules/input/gtkimcontextxim.c (gtk_im_context_xim_filter_keypress): Handle key releases as well as presses.
Diffstat (limited to 'gtk/gtkwidget.c')
-rw-r--r--gtk/gtkwidget.c68
1 files changed, 34 insertions, 34 deletions
diff --git a/gtk/gtkwidget.c b/gtk/gtkwidget.c
index 2f3229081a..10f6241f1a 100644
--- a/gtk/gtkwidget.c
+++ b/gtk/gtkwidget.c
@@ -6167,9 +6167,9 @@ gtk_widget_style_get (GtkWidget *widget,
/**
* gtk_widget_path:
* @widget: a #GtkWidget
* @path_length_p: location to store length of the path, or %NULL
* @path_p: location to store allocated path string, or %NULL
* @path_reversed_p: location to store allocated reverse path string, or %NULL
*
* Obtains the full path to @widget. The path is simply the name of a
* widget and all its parents in the container hierarchy, separated by
@@ -6187,12 +6187,12 @@ gtk_widget_style_get (GtkWidget *widget,
**/
void
gtk_widget_path (GtkWidget *widget,
- guint *path_length_p,
- gchar **path_p,
- gchar **path_reversed_p)
+ guint *path_length,
+ gchar **path,
+ gchar **path_reversed)
{
static gchar *rev_path = NULL;
- static guint path_len = 0;
+ static guint tmp_path_len = 0;
guint len;
g_return_if_fail (GTK_IS_WIDGET (widget));
@@ -6207,10 +6207,10 @@ gtk_widget_path (GtkWidget *widget,
string = gtk_widget_get_name (widget);
l = strlen (string);
- while (path_len <= len + l + 1)
+ while (tmp_path_len <= len + l + 1)
{
- path_len += INIT_PATH_SIZE;
- rev_path = g_realloc (rev_path, path_len);
+ tmp_path_len += INIT_PATH_SIZE;
+ rev_path = g_realloc (rev_path, tmp_path_len);
}
s = string + l - 1;
d = rev_path + len;
@@ -6227,23 +6227,23 @@ gtk_widget_path (GtkWidget *widget,
}
while (widget);
- if (path_length_p)
- *path_length_p = len - 1;
- if (path_reversed_p)
- *path_reversed_p = g_strdup (rev_path);
- if (path_p)
+ if (path_length)
+ *path_length = len - 1;
+ if (path_reversed)
+ *path_reversed = g_strdup (rev_path);
+ if (path)
{
- *path_p = g_strdup (rev_path);
- g_strreverse (*path_p);
+ *path = g_strdup (rev_path);
+ g_strreverse (*path);
}
}
/**
* gtk_widget_class_path:
* @widget: a #GtkWidget
* @path_length_p: location to store the length of the class path, or %NULL
* @path_p: location to store the class path as an allocated string, or %NULL
* @path_reversed_p: location to store the reverse class path as an allocated string, or %NULL
*
* Same as gtk_widget_path(), but always uses the name of a widget's type,
* never uses a custom name set with gtk_widget_set_name().
@@ -6251,12 +6251,12 @@ gtk_widget_path (GtkWidget *widget,
**/
void
gtk_widget_class_path (GtkWidget *widget,
- guint *path_length_p,
- gchar **path_p,
- gchar **path_reversed_p)
+ guint *path_length,
+ gchar **path,
+ gchar **path_reversed)
{
static gchar *rev_path = NULL;
- static guint path_len = 0;
+ static guint tmp_path_len = 0;
guint len;
g_return_if_fail (GTK_IS_WIDGET (widget));
@@ -6271,10 +6271,10 @@ gtk_widget_class_path (GtkWidget *widget,
string = gtk_type_name (GTK_WIDGET_TYPE (widget));
l = strlen (string);
- while (path_len <= len + l + 1)
+ while (tmp_path_len <= len + l + 1)
{
- path_len += INIT_PATH_SIZE;
- rev_path = g_realloc (rev_path, path_len);
+ tmp_path_len += INIT_PATH_SIZE;
+ rev_path = g_realloc (rev_path, tmp_path_len);
}
s = string + l - 1;
d = rev_path + len;
@@ -6291,14 +6291,14 @@ gtk_widget_class_path (GtkWidget *widget,
}
while (widget);
- if (path_length_p)
- *path_length_p = len - 1;
- if (path_reversed_p)
- *path_reversed_p = g_strdup (rev_path);
- if (path_p)
+ if (path_length)
+ *path_length = len - 1;
+ if (path_reversed)
+ *path_reversed = g_strdup (rev_path);
+ if (path)
{
- *path_p = g_strdup (rev_path);
- g_strreverse (*path_p);
+ *path = g_strdup (rev_path);
+ g_strreverse (*path);
}
}
@@ -6167,9 +6167,9 @@ gtk_widget_style_get (GtkWidget *widget,
* gtk_widget_path:
* @widget: a #GtkWidget
- * @path_length_p: location to store length of the path, or %NULL
- * @path_p: location to store allocated path string, or %NULL
- * @path_reversed_p: location to store allocated reverse path string, or %NULL
+ * @path_length: location to store length of the path, or %NULL
+ * @path: location to store allocated path string, or %NULL
+ * @path_reversed: location to store allocated reverse path string, or %NULL
*
* Obtains the full path to @widget. The path is simply the name of a
@@ -6227,23 +6227,23 @@ gtk_widget_path (GtkWidget *widget,
* gtk_widget_class_path:
* @widget: a #GtkWidget
- * @path_length_p: location to store the length of the class path, or %NULL
- * @path_p: location to store the class path as an allocated string, or %NULL
- * @path_reversed_p: location to store the reverse class path as an allocated string, or %NULL
+ * @path_length: location to store the length of the class path, or %NULL
+ * @path: location to store the class path as an allocated string, or %NULL
+ * @path_reversed: location to store the reverse class path as an allocated string, or %NULL
*
* Same as gtk_widget_path(), but always uses the name of a widget's type,